@@ -8,6 +8,8 @@
 	if (!missing(method)) { 
 		if (method=='bilinear') {
 			return( TRUE )
+		} else {
+			warning('unknown "method". Should be "method=bilinear", or absent')
 		}
 	}
 	return(FALSE)
@@ -17,7 +19,7 @@
 if (!isGeneric("disaggregate")) {
 	setGeneric("disaggregate", function(x, fact, ...)
 		standardGeneric("disaggregate"))
-}	
+}
 
 setMethod('disaggregate', signature(x='RasterLayer', fact='numeric'), 
 function(x, fact, filename='', ...) {
@@ -50,38 +52,39 @@ function(x, fact, filename='', ...) {
 	}
 	
 	
-	if ((!canProcessInMemory(outraster, 3)) && filename == '') {
-		filename <- rasterTmpFile()
-								
-	}
+	if (canProcessInMemory(outraster, 3)) { 
 	
-	if ( filename == "" ) {
-		if (dataContent(x) != 'all') {
-			x <- readAll(x)
-		}
 		cols <- rep(rep(1:ncol(x), each=xfact), times=nrow(x)*yfact)
 		rows <- rep(1:nrow(x), each=ncol(x)*xfact*yfact)
 		cells <- cellFromRowCol(x, rows, cols)
-		outraster <- setValues(outraster, values(x)[cells])
+		outraster <- setValues(outraster, getValues(x)[cells])
+
+		if (filename != '') {
+			outraster <- writeRaster(outraster, filename=filename,...)
+		}
 		
 	} else { 
-		# to speed up valuesRow
+		if (filename == '') {
+			filename <- rasterTmpFile()						
+		}
+	# to speed up getValues
 		if (dataContent(x) != 'all') { x <- clearValues(x) }
 		v <- vector(length=0)
-		cols <- rep(1:ncol(x), each=xfact)
+		cols <- rep(rep(1:ncol(x), each=xfact), times=yfact)
 
-				
 		pb <- pbCreate(nrow(x), type=.progress(...))
+		outraster <- writeStart(outraster, filename=filename, datatype=dataType(x), ...)
 		for (r in 1:nrow(x)) {
 			vals <- getValues(x, r)
-			for (i in 1:yfact) {
-				outraster <- setValues(outraster, vals[cols], (r-1) * xfact + i)
-				outraster <- writeRaster(outraster, filename=filename, ...)
-			}	
+			rown <- (r-1) * xfact + 1
+			outraster <- writeValues(outraster, vals[cols], rown)
 			pbStep(pb, r)
 		}
+		outraster <- writeStop(outraster)
 		pbClose(pb)
 	}
+
 	return(outraster)
 }
 )
+
