@@ -11,7 +11,7 @@ pbCreate <- function(nsteps, type, style=3) {
 		require(tcltk)
 		pb <- tkProgressBar(title="progress bar", min=0, max=nsteps, width = 300)
 	} else if (type == 'windows') {
-		if (substr( R.Version()$platform, 1, 7) == "i386-pc" ) {
+		if (.Platform$OS.type == "windows" ) {
 			pb <- winProgressBar(title="progress bar", min=0 , max=nsteps, width = 300)
 		} else {
 			pb <- tkProgressBar(title="progress bar", min=0, max=nsteps, width = 300)
@@ -24,13 +24,17 @@ pbCreate <- function(nsteps, type, style=3) {
 }
 
 
-pbStep <- function(pb, step, label='step') {
+
+pbStep <- function(pb, step=NULL, label='step') {
 	pbclass <- class(pb)
 	if (pbclass=="txtProgressBar") {
+		if (is.null(step)) { step = pb$getVal() + 1 }
 		setTxtProgressBar(pb, step)
 	} else if (pbclass=="tkProgressBar") {
+		if (is.null(step)) { step = pb$getVal() + 1 }
 		setTkProgressBar(pb, step, label=paste(label, step))	
 	} else if (pbclass=="winProgressBar") {
+		if (is.null(step)) { step <- getWinProgressBar(pb)+1  }
 		setWinProgressBar(pb, step, title=paste(label, step))	
 	} 
 }
