@@ -23,9 +23,9 @@ xFromCol <- function(object, colnr) {
 
 cellFromXY <- function(object, xy) {
 	object <- raster(object)
-	if (class(xy) == 'SpatialPoints' | class(xy) == 'SpatialPointsDataFrame') {
-		x <- coordinates(xy)[,1]
-		y <- coordinates(xy)[,2]
+	if (inherits(xy, 'Spatial')) {
+		x <- xy@coords[,1]
+		y <- xy@coords[,2]
 	} else if (is.null(dim(xy))) { 
 		x <- xy[1]
 		y <- xy[2] 
@@ -42,9 +42,11 @@ cellFromXY <- function(object, xy) {
 
 colFromX <- function ( object, x )	{
 	object <- raster(object)
-	if (class(x) == 'SpatialPoints' | class(x) == 'SpatialPointsDataFrame') {	x <- x@points[,1] }
-	colnr <- (trunc((x - xmin(object)) / xres(object))) + 1 
-	colnr[x == xmax(object)] <- ncol(object)
+	if (inherits(x, 'Spatial')) { 
+		x <- x@coords[,1] 
+	}
+	colnr <- trunc((x - xmin(object)) / xres(object)) + 1 
+	colnr[x == xmax(object)] <- object@ncols
 	colnr[x < xmin(object) | x > xmax(object) ] <- NA
 	return(as.vector(colnr))
 }
@@ -52,7 +54,9 @@ colFromX <- function ( object, x )	{
 	
 rowFromY <- function ( object, y )	{
 	object <- raster(object)
-	if (class(y) == 'SpatialPoints' | class(y) == 'SpatialPointsDataFrame') {	y <- y@points[,2] }
+	if (inherits(y, 'Spatial')) {
+		y <- y@coords[,2] 
+	}
 	rownr <- 1 + (trunc((ymax(object) - y) / yres(object)))
 	rownr[y == ymin(object) ] <- nrow(object) 
 	rownr[y > ymax(object) | y < ymin(object)] <- NA
@@ -60,16 +64,15 @@ rowFromY <- function ( object, y )	{
 }	
 	
 
-xyFromCell <- function(object, cell, asSpatialPoints=FALSE) {
+xyFromCell <- function(object, cell, spatial=FALSE) {
 	object <- raster(object)
-	cell <- round(cell)
 	xy <- matrix(data = NA, ncol=2, nrow=length(cell))
 	colnr <- colFromCell(object, cell)
 	rownr <- rowFromCell(object, cell)
 	xy[,1] <- xFromCol(object, colnr)
 	xy[,2] <- yFromRow(object, rownr) 		
 	colnames(xy) <- c("x", "y")
-	if (asSpatialPoints) {
+	if (spatial) {
 		xy <- SpatialPoints(xy, projection(object, asText=FALSE))
 	}
 	return(xy)
@@ -78,7 +81,6 @@ xyFromCell <- function(object, cell, asSpatialPoints=FALSE) {
 
 yFromCell <- function(object, cell) {
 	object <- raster(object)
-	cell <- round(cell)
 	rownr <- rowFromCell(object, cell)
 	y <- yFromRow(object, rownr) 		
 	return(y)
@@ -86,7 +88,6 @@ yFromCell <- function(object, cell) {
 	
 xFromCell <- function(object, cell) {
 	object <- raster(object)
-	cell <- round(cell)
 	colnr <- colFromCell(object, cell)
 	x <- xFromCol(object, colnr)
 	return(x)
